Build regex keyword patterns from a variable map config
Source:R/match_columns.R
build_keyword_patterns.RdFor each variable with a keywords: block, produces a single regex that
matches any of those keywords as a substring not immediately surrounded by
other alphanumeric characters (so kjonn matches io_kjonn but not
kjonnstudie).
Arguments
- config
List with a
$var_mapelement (fromload_config()).- min_char
Minimum keyword length to include. Default
3.